<?php
namespace Teknisa\CMP\Modules\Solicitacao\Modules\Relatorios\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class Cmp03200AlteracaoDosProdutosDaSolicitacao extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $qr2Strategy;
    protected $newCode;
    protected $environment;
    protected $connection;
    protected $dataSourceManager;

    public function __construct($reportService, $entityManager, $qr2Strategy, $newCode, $environment, $connection, $dataSourceManager) {
        $this->entityManager        = $entityManager;
        $this->qr2Strategy          = $qr2Strategy;
        $this->reportService        = $reportService;
        $this->newCode              = $newCode;
        $this->environment          = $environment;
        $this->connection           = $connection;
        $this->dataSourceManager    = $dataSourceManager;
    }

    protected $reportMapping = array (
        'CMP03200' =>
            array (
                'strategy' => 'QR2',
                'parameterMapping' =>
                    array (
                        'NRLISTA' => 'L_CDFILSOLMOV',
                        'DTINI' => 'P_DENTRINI',
                        'DTFIM' => 'P_DENTRFIN',
                        'DTENTRINI' => 'P_DTENTRINI',
                        'DTENTRFIN' => 'P_DTENTRFIN',
                        'SOLEXC' => 'P_SOLEXC',
                        'PRODUTO' => 'L_PRODUTO',
                        'CDPRODINI' => 'P_PRODINI',
                        'PRODUTOFINAL' => 'P_PRODFIN',
                        'CDPRODFIN' => 'P_PRODFINTEXT'

                    ),
            ),
        
    );
    
     public function insertLista($nrlista, $cdllista) {
    	$params = array(
    		"NRLISTA" => $nrlista,
    		"CDLISTA" => $cdllista
    	);
    	
    	$sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    }
    
    public function buscaTodasUnidades($nrorg) {
        $unidades = array();
        
        $conditions = array(
            [
                "columnName" => "NRORG",
                "operator"   => "=",
                "value"      => $nrorg
            ]
        );
        
        $filterCriteria = new \Zeedhi\Framework\DataSource\FilterCriteria('cmp03200_filial_movopsol', $conditions);
        $listaUnidades = $this->dataSourceManager->findBy($filterCriteria)->getRows();
        
        foreach($listaUnidades as $unidade){
            array_push($unidades, $unidade['CDFILIAL']);
        }
        
        return $unidades;
    }

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        ini_set('default_socket_timeout', 10000);
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrg();
        $row['NRLISTA'] = $this->newCode->getCodeByTableName('LISTA', $nrorg, 1, 10, false);
        
        if($row['ALLCDFILIAL'] === 'T'){
            $filiais = $this->buscaTodasUnidades($nrorg);
        } else{
            $filiais = $row['CDFILIAL'];
        }
        
        foreach ($filiais as $filial) {
            $this->insertLista($row['NRLISTA'], $filial);
        }
        
        $row['__report_name'] = $row['REPORT_NAME'];
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
    }
}